@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-#   Copyright (c) 2008-2012, David P. D. Moss. All rights reserved.
+#   Copyright (c) 2008-2015, David P. D. Moss. All rights reserved.
 #
 #   Released under the BSD license. See the LICENSE file for details.
 #-----------------------------------------------------------------------------
@@ -7,37 +7,24 @@
 
 import sys as _sys
 import struct as _struct
-import socket as _socket
 
+from socket import inet_aton as _inet_aton
 #   Check whether we need to use fallback code or not.
 if _sys.platform in ('win32', 'cygwin'):
     #   inet_pton() not available on Windows. inet_pton() under cygwin
     #   behaves exactly like inet_aton() and is therefore highly unreliable.
-    from _socket import inet_aton as _inet_aton, inet_ntoa as _inet_ntoa
     from netaddr.fbsocket import inet_pton as _inet_pton, AF_INET
 else:
-    #   All other cases, attempt to use all functions from the socket module.
-    try:
-        #   A common bug on older implementations of the socket module.
-        _socket.inet_aton('255.255.255.255')
-
-        from _socket import inet_aton as _inet_aton, inet_ntoa as _inet_ntoa, \
-                            inet_pton as _inet_pton, AF_INET
-    except:
-        #   Use the fallback socket code.
-        from netaddr.fbsocket import inet_aton as _inet_aton, \
-                                     inet_ntoa as _inet_ntoa, \
-                                     inet_pton as _inet_pton, AF_INET
+    #   All other cases, use all functions from the socket module.
+    from socket import inet_pton as _inet_pton, AF_INET
 
 from netaddr.core import AddrFormatError, ZEROFILL, INET_PTON
 
-from netaddr.strategy import valid_words  as _valid_words, \
-    valid_bits   as _valid_bits, \
-    bits_to_int  as _bits_to_int, \
-    int_to_bits  as _int_to_bits, \
-    valid_bin    as _valid_bin, \
-    int_to_bin   as _int_to_bin, \
-    bin_to_int   as _bin_to_int
+from netaddr.strategy import (
+    valid_words as _valid_words, valid_bits as _valid_bits,
+    bits_to_int as _bits_to_int, int_to_bits as _int_to_bits,
+    valid_bin as _valid_bin, int_to_bin as _int_to_bin,
+    bin_to_int as _bin_to_int)
 
 from netaddr.compat import _str_type
 
@@ -76,21 +63,21 @@ max_word = 2 ** word_size - 1
 
 #: A dictionary mapping IPv4 CIDR prefixes to the equivalent netmasks.
 prefix_to_netmask = dict(
-    [(i, max_int ^ (2 ** (width - i) - 1)) for i in range(0, width+1)])
+    [(i, max_int ^ (2 ** (width - i) - 1)) for i in range(0, width + 1)])
 
 #: A dictionary mapping IPv4 netmasks to their equivalent CIDR prefixes.
 netmask_to_prefix = dict(
-    [(max_int ^ (2 ** (width - i) - 1), i) for i in range(0, width+1)])
+    [(max_int ^ (2 ** (width - i) - 1), i) for i in range(0, width + 1)])
 
 #: A dictionary mapping IPv4 CIDR prefixes to the equivalent hostmasks.
 prefix_to_hostmask = dict(
-    [(i, (2 ** (width - i) - 1)) for i in range(0, width+1)])
+    [(i, (2 ** (width - i) - 1)) for i in range(0, width + 1)])
 
 #: A dictionary mapping IPv4 hostmasks to their equivalent CIDR prefixes.
 hostmask_to_prefix = dict(
-    [((2 ** (width - i) - 1), i) for i in range(0, width+1)])
+    [((2 ** (width - i) - 1), i) for i in range(0, width + 1)])
+
 
-#-----------------------------------------------------------------------------
 def valid_str(addr, flags=0):
     """
     :param addr: An IPv4 address in presentation (string) format.
@@ -114,12 +101,12 @@ def valid_str(addr, flags=0):
             _inet_pton(AF_INET, addr)
         else:
             _inet_aton(addr)
-    except:
+    except Exception:
         validity = False
 
     return validity
 
-#-----------------------------------------------------------------------------
+
 def str_to_int(addr, flags=0):
     """
     :param addr: An IPv4 dotted decimal address in string form.
@@ -138,10 +125,10 @@ def str_to_int(addr, flags=0):
             return _struct.unpack('>I', _inet_pton(AF_INET, addr))[0]
         else:
             return _struct.unpack('>I', _inet_aton(addr))[0]
-    except:
+    except Exception:
         raise AddrFormatError('%r is not a valid IPv4 address string!' % addr)
 
-#-----------------------------------------------------------------------------
+
 def int_to_str(int_val, dialect=None):
     """
     :param int_val: An unsigned integer.
@@ -153,15 +140,14 @@ def int_to_str(int_val, dialect=None):
     """
     if 0 <= int_val <= max_int:
         return '%d.%d.%d.%d' % (
-             int_val >> 24,
+            int_val >> 24,
             (int_val >> 16) & 0xff,
-            (int_val >>  8) & 0xff,
-             int_val & 0xff)
+            (int_val >> 8) & 0xff,
+            int_val & 0xff)
     else:
-        raise ValueError('%r is not a valid 32-bit unsigned integer!' \
-            % int_val)
+        raise ValueError('%r is not a valid 32-bit unsigned integer!' % int_val)
+
 
-#-----------------------------------------------------------------------------
 def int_to_arpa(int_val):
     """
     :param int_val: An unsigned integer.
@@ -174,7 +160,7 @@ def int_to_arpa(int_val):
     words.extend(['in-addr', 'arpa', ''])
     return '.'.join(words)
 
-#-----------------------------------------------------------------------------
+
 def int_to_packed(int_val):
     """
     :param int_val: the integer to be packed.
@@ -184,7 +170,7 @@ def int_to_packed(int_val):
     """
     return _struct.pack('>I', int_val)
 
-#-----------------------------------------------------------------------------
+
 def packed_to_int(packed_int):
     """
     :param packed_int: a packed string containing an unsigned integer.
@@ -195,11 +181,11 @@ def packed_to_int(packed_int):
     """
     return _struct.unpack('>I', packed_int)[0]
 
-#-----------------------------------------------------------------------------
+
 def valid_words(words):
     return _valid_words(words, word_size, num_words)
 
-#-----------------------------------------------------------------------------
+
 def int_to_words(int_val):
     """
     :param int_val: An unsigned integer.
@@ -208,14 +194,14 @@ def int_to_words(int_val):
         represented by an unsigned integer.
     """
     if not 0 <= int_val <= max_int:
-        raise ValueError('%r is not a valid integer value supported ' \
-            'by this address type!' % int_val)
+        raise ValueError('%r is not a valid integer value supported by'
+                         'this address type!' % int_val)
     return ( int_val >> 24,
             (int_val >> 16) & 0xff,
             (int_val >>  8) & 0xff,
              int_val & 0xff)
 
-#-----------------------------------------------------------------------------
+
 def words_to_int(words):
     """
     :param words: A list or tuple containing integer octets.
@@ -224,37 +210,36 @@ def words_to_int(words):
         by word (octet) sequence.
     """
     if not valid_words(words):
-        raise ValueError('%r is not a valid octet list for an IPv4 ' \
-            'address!' % words)
+        raise ValueError('%r is not a valid octet list for an IPv4 address!' % words)
     return _struct.unpack('>I', _struct.pack('4B', *words))[0]
 
-#-----------------------------------------------------------------------------
+
 def valid_bits(bits):
     return _valid_bits(bits, width, word_sep)
 
-#-----------------------------------------------------------------------------
+
 def bits_to_int(bits):
     return _bits_to_int(bits, width, word_sep)
 
-#-----------------------------------------------------------------------------
+
 def int_to_bits(int_val, word_sep=None):
     if word_sep is None:
         word_sep = globals()['word_sep']
     return _int_to_bits(int_val, word_size, num_words, word_sep)
 
-#-----------------------------------------------------------------------------
+
 def valid_bin(bin_val):
     return _valid_bin(bin_val, width)
 
-#-----------------------------------------------------------------------------
+
 def int_to_bin(int_val):
     return _int_to_bin(int_val, width)
 
-#-----------------------------------------------------------------------------
+
 def bin_to_int(bin_val):
     return _bin_to_int(bin_val, width)
 
-#-----------------------------------------------------------------------------
+
 def expand_partial_address(addr):
     """
     Expands a partial IPv4 address into a full 4-octet version.
@@ -273,13 +258,13 @@ def expand_partial_address(addr):
             #   Ignore IPv6 ...
             raise error
 
-        if '.' in addr:
-            tokens = ['%d' % int(o) for o in addr.split('.')]
-        else:
-            try:
+        try:
+            if '.' in addr:
+                tokens = ['%d' % int(o) for o in addr.split('.')]
+            else:
                 tokens = ['%d' % int(addr)]
-            except ValueError:
-                raise error
+        except ValueError:
+            raise error
 
         if 1 <= len(tokens) <= 4:
             for i in range(4 - len(tokens)):
